==> haskell-skylighting-core-0.7.3-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-skylighting-core.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skylighting-core
version: 0.7.3
id: skylighting-core-0.7.3-1ptTFlBJkrkGStw1Nm9swW
key: skylighting-core-0.7.3-1ptTFlBJkrkGStw1Nm9swW
license: BSD-3-Clause
copyright: (C) 2016-2018 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: https://github.com/jgm/skylighting
synopsis: syntax highlighting library
description:
    Skylighting is a syntax highlighting library.
    It derives its tokenizers from XML syntax
    definitions used by KDE'\''s KSyntaxHighlighting
    framework, so any syntax supported by that
    framework can be added. An optional command-line
    program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides the core highlighting
    functionality under a permissive license. It also
    bundles XML parser definitions licensed under the
    GPL.
category: Text
abi: 4e2a0f306bd5e8d22a598eb76cce5d16
exposed: True
exposed-modules:
    Skylighting.Core Skylighting.Format.ANSI Skylighting.Format.HTML
    Skylighting.Format.LaTeX Skylighting.Loader Skylighting.Parser
    Skylighting.Regex Skylighting.Styles Skylighting.Tokenizer
    Skylighting.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/skylighting-core-0.7.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/skylighting-core-0.7.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/skylighting-core-0.7.3
hs-libraries: HSskylighting-core-0.7.3-1ptTFlBJkrkGStw1Nm9swW
depends:
    base-4.11.1.0 mtl-2.2.2 transformers-0.5.5.0 text-1.2.3.0
    binary-0.8.5.1 bytestring-0.10.8.2 directory-1.3.1.5 filepath-1.4.2
    aeson-1.4.0.0-2fzGzKiyJUwJpJnaq3iWXS
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    attoparsec-0.13.2.2-5oKqcFqqk8HLoRElqn64fK
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    hxt-9.3.1.16-Lr69hF4oLUy8lzl1tKCl5P
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-html-0.9.1.1-EgxdH3AtVL83pCluZdDgeJ containers-0.5.11.0
    ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1
    colour-2.3.4-C3PVIHDZkyCIpOJGl3M0hE
    regex-pcre-0.94.4-4rpGue7olxL5eWtXZFv4hv
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             aeson-1.4.0.0-2fzGzKiyJUwJpJnaq3iWXS=1a1b9e384095a5a09c623b25305bd94d
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             attoparsec-0.13.2.2-5oKqcFqqk8HLoRElqn64fK=fff7ae21f45c1b0af12007963cebbf81
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
             hxt-9.3.1.16-Lr69hF4oLUy8lzl1tKCl5P=be88e93269229a8af3cc92dec8098755
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=42026212d0dad8beaed25fde58365be8
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             blaze-html-0.9.1.1-EgxdH3AtVL83pCluZdDgeJ=26d7d7bc6469699c9d8f038081c294ce
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1=3720aeddf087c27668b5c651df34c2d3
             colour-2.3.4-C3PVIHDZkyCIpOJGl3M0hE=a833f5ee389bbe28de815ccdd9dc961e
             regex-pcre-0.94.4-4rpGue7olxL5eWtXZFv4hv=cd8a991f2d7b99d9774d2361006f4ec4
haddock-interfaces: /usr/share/doc/haskell-skylighting-core/html/skylighting-core.haddock
haddock-html: /usr/share/doc/haskell-skylighting-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-core-0.7.3-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-skylighting-core.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skylighting-core
version: 0.7.3
id: skylighting-core-0.7.3-ESffrGdiIpRKWWSFyzj0ya
key: skylighting-core-0.7.3-ESffrGdiIpRKWWSFyzj0ya
license: BSD-3-Clause
copyright: (C) 2016-2018 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: https://github.com/jgm/skylighting
synopsis: syntax highlighting library
description:
    Skylighting is a syntax highlighting library.
    It derives its tokenizers from XML syntax
    definitions used by KDE'\''s KSyntaxHighlighting
    framework, so any syntax supported by that
    framework can be added. An optional command-line
    program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides the core highlighting
    functionality under a permissive license. It also
    bundles XML parser definitions licensed under the
    GPL.
category: Text
abi: 1750b2d522e211b01e161fddaffe30db
exposed: True
exposed-modules:
    Skylighting.Core Skylighting.Format.ANSI Skylighting.Format.HTML
    Skylighting.Format.LaTeX Skylighting.Loader Skylighting.Parser
    Skylighting.Regex Skylighting.Styles Skylighting.Tokenizer
    Skylighting.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/skylighting-core-0.7.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/skylighting-core-0.7.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/skylighting-core-0.7.3
hs-libraries: HSskylighting-core-0.7.3-ESffrGdiIpRKWWSFyzj0ya
depends:
    base-4.11.1.0 mtl-2.2.2 transformers-0.5.5.0 text-1.2.3.0
    binary-0.8.5.1 bytestring-0.10.8.2 directory-1.3.1.5 filepath-1.4.2
    aeson-1.4.0.0-CakggGCi8AH730RFzdp4vh
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    hxt-9.3.1.16-Lr69hF4oLUy8lzl1tKCl5P
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-html-0.9.1.1-EgxdH3AtVL83pCluZdDgeJ containers-0.5.11.0
    ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1
    colour-2.3.4-C3PVIHDZkyCIpOJGl3M0hE
    regex-pcre-0.94.4-4rpGue7olxL5eWtXZFv4hv
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             aeson-1.4.0.0-CakggGCi8AH730RFzdp4vh=7bc5561c9bccdf225964aec1dc0920a0
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ=b8f8a17746566009aae6e9799affc625
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
             hxt-9.3.1.16-Lr69hF4oLUy8lzl1tKCl5P=be88e93269229a8af3cc92dec8098755
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=42026212d0dad8beaed25fde58365be8
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             blaze-html-0.9.1.1-EgxdH3AtVL83pCluZdDgeJ=26d7d7bc6469699c9d8f038081c294ce
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1=3720aeddf087c27668b5c651df34c2d3
             colour-2.3.4-C3PVIHDZkyCIpOJGl3M0hE=a833f5ee389bbe28de815ccdd9dc961e
             regex-pcre-0.94.4-4rpGue7olxL5eWtXZFv4hv=cd8a991f2d7b99d9774d2361006f4ec4
haddock-interfaces: /usr/share/doc/haskell-skylighting-core/html/skylighting-core.haddock
haddock-html: /usr/share/doc/haskell-skylighting-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
